//---------------------------------------------------------------------------

#ifndef VmsCommInfoFH
#define VmsCommInfoFH
//---------------------------------------------------------------------------
#include "CenterCommF.h"
#include "CDSVmsCtlrF.h"
//---------------------------------------------------------------------------

TVmsCtlr *FindVms(String ACtrlId);

String VmsOperMode(TVmsCtlr *AObj);
String VmsComm(TVmsCtlr *AObj);
String VmsModuleState(TVmsCtlr *AObj);
String VmsModulePower(TVmsCtlr *AObj);
String VmsModuleLuminance(TVmsCtlr *AObj);
String VmsModuleDoor(TVmsCtlr *AObj);
String VmsModuleFan(TVmsCtlr *AObj);
String VmsModuleHeater(TVmsCtlr *AObj);
String VmsModuleTemp(TVmsCtlr *AObj);

#endif
